@@ -31,8 +31,9 @@ class RubyRunner(Runner):
         files[filename] = code
         return files
 
-    def require(self, path, module_name):
+    def require(self, path, module_name_):
         files = dict()
+        module_name = os.path.normpath(module_name_)
         if module_name in self.required:
             return files
         module_file = module_name + '.rb'
@@ -46,10 +47,10 @@ class RubyRunner(Runner):
 class RubyCLI(CLI):
 
     def __init__(self, compiler=None):
-        super(RubyCLI, self).__init__('Ruby', compiler, False)
+        super(RubyCLI, self).__init__('Ruby', compiler, False, False)
 
     def get_runner(self, args, options):
-        return RubyRunner(args.language, args.compiler, args.save, args.encoding, args.retry, args.retry_wait, False)
+        return RubyRunner(args.language, args.compiler, args.save, args.encoding, args.retry, args.retry_wait)
 
 
 def ruby(compiler=None):
